import GroupService from '../services/group.js';
import UserService from '../services/user.js';
import jwt from 'jsonwebtoken';
import config from '../../config.json' with {type: "json"};
import log from '../utils/log.js';
import translate from '../utils/translate.js';
import responseCodes from '../response/responseCodes.js';

const TAG = "/controllers/group.js";

class GroupController {
    async create(req, res) {
        let { groupName } = req.params;

        let user = jwt.decode(req.headers.authorization.split(' ')[1], config.secret);
        let group = await GroupService.create(groupName, user.login.id);

        log.info(`New group with name ${groupName} was just created by user ${user.login.username}`);

        await UserService.joinGroup(user.login.id, group.id);
        // return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
        return res.status(200).send(group.id.toString())
    }
    async join(req, res) {
        let { groupId } = req.params;

        let user = jwt.decode(req.headers.authorization.split(' ')[1], config.secret);
        await UserService.joinGroup(user.login.id, groupId);

        log.info(`User ${user.login.username} has just joined group with ID ${groupId}`);
        return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
    }

    async updatePassword(req, res) {
        let { groupId } = req.params;
        let { password } = req.body;

        await GroupService.updatePassword(groupId, password);
        log.info(`Password for group with ID ${groupId} was updated`);

        return res.status(200).send(translate(req.headers["accept-language"], responseCodes.responses.general.ok));
    }

    async getByName(req, res) {
        let groupName = req.params.groupName || req.body.groupName;

        let group = await GroupService.getByName(groupName);

        return res.status(200).send(group["id"].toString());
    }

    async getById(req, res) {
        let groupId = req.params.groupId;

        let groupName = (await GroupService.getById(groupId)).name;

        return res.status(200).send(groupName);
    }

    async getUsersInGroup(req, res) {

        const groupId = req.params.groupId;

        let result = await GroupService.getUsersInGroup(groupId);

        return res.status(200).send(result);
    }

    async getAdminId(req, res) {
        const groupId = req.params.groupId;

        let result = await GroupService.getAdminId(groupId);

        if (!result) result = -1

        return res.status(200).send(result.toString())
    }
}

export default new GroupController();
