import { Router } from 'express';
import auth from '../middlewares/auth.js';
import UserController from '../controllers/user.js';
import tryHandler from '../response/errorHandler.js';

const UserRouter = new Router();

UserRouter.post('/register', tryHandler(auth.requireUsername), tryHandler(auth.requirePassword), tryHandler(UserController.register));
UserRouter.post('/login', tryHandler(auth.requireUsername), tryHandler(auth.requirePassword), tryHandler(UserController.login));
UserRouter.get('/synchronize/:groupId', tryHandler(auth.authenticate), tryHandler(auth.userIsInGroup), tryHandler(UserController.synchronize));
UserRouter.post('/changeUsername', tryHandler(auth.authenticate), tryHandler(auth.requireUsername), tryHandler(UserController.changeUsername));
UserRouter.post('/changePassword', tryHandler(auth.authenticate), tryHandler(auth.requirePassword), tryHandler(UserController.changePassword));
UserRouter.get('/myGroups', tryHandler(auth.authenticate), tryHandler(UserController.getAllGroupsForUser));
//Maybe I should add a middleware like "auth.usersShareGroups" 
UserRouter.get('/byId/:userId', tryHandler(auth.authenticate), tryHandler(UserController.getById))

export default UserRouter;